@@ -34,18 +34,6 @@ test_that("error stack is passed", {
 
   expect_true("call" %in% names(err))
   expect_true(inherits(err, "error"))
-  expect_true(inherits(err, "callrError"))
+  expect_true(inherits(err, "callr_error"))
   expect_equal(length(err$stack), 3)
 })
-
-test_that("debugger is called", {
-
-  called <- FALSE
-
-  with_mock(
-    `utils::debugger` = function(...) called <<- TRUE,
-    r(function() { 1 + "A" }, error = "debugger")
-  )
-
-  expect_true(called)
-})
