@@ -6,7 +6,7 @@ test_that("r", {
   withr::with_options(
     list(repos = "foobar"),
     expect_equal(
-      r(function() getOption("repos"),
+      r_copycat(function() getOption("repos"),
         user_profile = FALSE,
         system_profile = FALSE
       ),
@@ -15,9 +15,10 @@ test_that("r", {
   )
 })
 
+## Need to supply libpath for covr...
 test_that("r_vanilla", {
   expect_equal(
-    r_vanilla(function() getOption("repos")),
+    r_vanilla(function() getOption("repos"), libpath = .libPaths()),
     "@CRAN@"
   )
 })
